==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/en_GB.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Your settings have been updated.",
"Activity" => "Activity",
"A file or folder has been <strong>shared</strong>" => "A file or folder has been <strong>shared</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "A new file or folder has been <strong>created</strong> in a shared folder",
"A file or folder has been <strong>changed</strong> in a shared folder" => "A file or folder has been <strong>changed</strong> in a shared folder",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "A file or folder has been <strong>deleted</strong> from a shared folder",
"You created %1\$s" => "You created %1\$s",
"%2\$s created %1\$s" => "%2\$s created %1\$s",
"You changed %1\$s" => "You changed %1\$s",
"%2\$s changed %1\$s" => "%2\$s changed %1\$s",
"You deleted %1\$s" => "You deleted %1\$s",
"%2\$s deleted %1\$s" => "%2\$s deleted %1\$s",
"You shared %1\$s with %2\$s" => "You shared %1\$s with %2\$s",
"You shared %1\$s with group %2\$s" => "You shared %1\$s with group %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s shared %1\$s with you",
"You shared %1\$s via link" => "You shared %1\$s via link",
"Activity notification" => "Activity notification",
"All Activities" => "All Activities",
"Activities by you" => "Activities by you",
"Activities by others" => "Activities by others",
"Shares" => "Shares",
"Files" => "Files",
"%s and %s" => "%s and %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>","%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s and %n more","%s and %n more"),
"Hello %s," => "Hello %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "You are receiving this email because the following things happened at %s in the last hour",
"You are receiving this email because in the last day the following things happened at %s" => "You are receiving this email because the following things happened at %s in the last day",
"You are receiving this email because in the last week the following things happened at %s" => "You are receiving this email because the following things happened at %s in the last week",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "You will see a list of events here when you start to use your %s.",
"No more events to load" => "No more events to load",
"Enable RSS feed" => "Enable RSS feed",
"Notifications" => "Notifications",
"Mail" => "Mail",
"Stream" => "Stream",
"You need to set up your email address before you can receive notification emails." => "You need to set up your email address before you can receive notification emails.",
"Send emails:" => "Send emails:",
"Hourly" => "Hourly",
"Daily" => "Daily",
"Weekly" => "Weekly",
"Activity feed" => "Activity feed",
"Personal activity feed for %s" => "Personal activity feed for %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/en_GB.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Your settings have been updated.",
"Activity" => "Activity",
"A file or folder has been <strong>shared</strong>" => "A file or folder has been <strong>shared</strong>",
"A new file or folder has been <strong>created</strong>" => "A new file or folder has been <strong>created</strong>",
"A file or folder has been <strong>changed</strong>" => "A file or folder has been <strong>changed</strong>",
"A file or folder has been <strong>deleted</strong>" => "A file or folder has been <strong>deleted</strong>",
"You created %1\$s" => "You created %1\$s",
"%2\$s created %1\$s" => "%2\$s created %1\$s",
"You changed %1\$s" => "You changed %1\$s",
"%2\$s changed %1\$s" => "%2\$s changed %1\$s",
"You deleted %1\$s" => "You deleted %1\$s",
"%2\$s deleted %1\$s" => "%2\$s deleted %1\$s",
"You shared %1\$s with %2\$s" => "You shared %1\$s with %2\$s",
"You shared %1\$s with group %2\$s" => "You shared %1\$s with group %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s shared %1\$s with you",
"You shared %1\$s via link" => "You shared %1\$s via link",
"Activity notification" => "Activity notification",
"All Activities" => "All Activities",
"Activities by you" => "Activities by you",
"Activities by others" => "Activities by others",
"Shares" => "Shares",
"Files" => "Files",
"%s and %s" => "%s and %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>","%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s and %n more","%s and %n more"),
"Hello %s," => "Hello %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "You are receiving this email because the following things happened at %s in the last hour",
"You are receiving this email because in the last day the following things happened at %s" => "You are receiving this email because the following things happened at %s in the last day",
"You are receiving this email because in the last week the following things happened at %s" => "You are receiving this email because the following things happened at %s in the last week",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "You will see a list of events here when you start to use your %s.",
"No more events to load" => "No more events to load",
"Enable RSS feed" => "Enable RSS feed",
"Notifications" => "Notifications",
"Mail" => "Mail",
"Stream" => "Stream",
"Notify about my own actions" => "Notify about my own actions",
"You need to set up your email address before you can receive notification emails." => "You need to set up your email address before you can receive notification emails.",
"Send emails:" => "Send emails:",
"Hourly" => "Hourly",
"Daily" => "Daily",
"Weekly" => "Weekly",
"Activity feed" => "Activity feed",
"Personal activity feed for %s" => "Personal activity feed for %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
